#!/bin/sh
#
#	Installation script for AIX 4.x colon files package
#

#
# Initialize variables
#


MSG_CAT_DIR="/usr/lib/lpd/pio/etc"
PREDEF_DIR="/usr/lib/lpd/pio/predef"
MSG_CAT_FILE="iiabt.cat"

PREDEF_FILES="ibm1759.pcl ibm1759.ps ibm1759.iq ibm1769.pcl ibm1769.ps ibm1769.iq "

FILE_OWNER="root"
FILE_GROUP="printq"
COLON_PERMS="0664"
MSG_CAT_PERMS="0664"
CHMOD="/usr/bin/chmod"
CHGRP="/usr/bin/chgrp"
CHOWN="/usr/bin/chown"

#
# confirm user input
#

confirm_user()
{
        rc=0
        if [ "$1" != "1" -a "${continue1}" = "yes" ];then
           rc=1
           return ${rc}
        fi
        if [ "$1" = "1" -a "${continue2}" = "yes" ];then
           echo "    AUTOMATIC OVERWRITE"
           rc=1
           return ${rc}
        fi

        if [ "$1" = "1" ]; then
                echo "        Continue .. (y/n/all/exit) [n]? \c"
        else
                echo "    Continue .. (n/y/all/exit) [n]? \c"
        fi
        read answer
        if [ "$answer" = "y" -o "$answer" = "yes" ]; then
                rc=1
                return $rc
        elif [ "$answer" = "exit" -o  "$answer" = "e" ]; then
             exit 0
        elif [ "$answer" = "all" -o "$answer" = "a" ]; then
                if [ "$1" = "1" ];then
                   continue2=yes
                else
                   continue1=yes
                fi
                rc=1
                return $rc
        fi
        return $rc
}


#
# The Script starts here  ....
#

#
# Check for root
#

if [ `whoami` != 'root' ]
then
        echo
        echo "PERMISSION DENIED"
        echo
        echo "You must be root to run this program."
        echo
        echo
        exit 1
fi


#
# display notice/message
#

clear
cat - << __END__


IBM Colon Files Installation Utility
(c) Copyright Lexmark International Inc., 2007
All Rights Reserved.
=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=

This utility will install the AIX Colon files into the
system directories. It will also install the message
catalog to the default location.

You will be prompted to install every Colon file before
it is installed on the system.

__END__


echo "Press ENTER to continue ...\c"
read x
echo
echo
#
# Install the colon files
#

#MVPRINTPACKAGE

rc=0

for i in $PREDEF_FILES
do
	file_name=`grep ":mL:" $i| sed -e 's/.*:://g'`
	echo "Installing [ $file_name ($i) ] ..."
	confirm_user 
	if [ "$rc" = "1" ]
	then
		if [ -f "$PREDEF_DIR/$i" ]
		then
			echo "    WARNING:"
			echo "       This printer already exists on your system .."
			confirm_user 1 
			if [ "$rc" = "1" ]
			then
				echo "    installing $i ... \c"
				cp $i $PREDEF_DIR/$i
				$CHOWN $FILE_OWNER $PREDEF_DIR/$i
				$CHGRP $FILE_GROUP $PREDEF_DIR/$i
				$CHMOD $COLON_PERMS $PREDEF_DIR/$i
				echo "done"
			else
				echo "Skipped at user request."
			fi
		else
			echo "    installing $i ... \c"
			cp $i $PREDEF_DIR/$i
			$CHOWN $FILE_OWNER $PREDEF_DIR/$i
			$CHGRP $FILE_GROUP $PREDEF_DIR/$i
			$CHMOD $COLON_PERMS $PREDEF_DIR/$i
			echo "done"
		fi
	else
		echo "    Skipped at user request."
	fi
	echo
done

#
# install the message catalog
#

echo "Installing [ $MSG_CAT_FILE ] ..."
confirm_user
if [ "$rc" = "1" ]
then
	if [ -f "$MSG_CAT_DIR/$MSG_CAT_FILE" ]
	then
		echo "    WARNING:"
		echo "       This message catalog already exits on your system .."
		confirm_user 1
		if [ "$rc" = "1" ]
		then
			echo "    installing $MSG_CAT_FILE ...\c"
			cp $MSG_CAT_FILE $MSG_CAT_DIR/$MSG_CAT_FILE
			$CHOWN $FILE_OWNER $MSG_CAT_DIR/$MSG_CAT_FILE
			$CHGRP $FILE_GROUP $MSG_CAT_DIR/$MSG_CAT_FILE
			$CHMOD $MSG_CAT_PERMS $MSG_CAT_DIR/$MSG_CAT_FILE
			echo "Done."
		else
			echo "    Skipped at user request."
		fi
	else
		echo "    installing $MSG_CAT_FILE ...\c"
		cp $MSG_CAT_FILE $MSG_CAT_DIR/$MSG_CAT_FILE
		$CHOWN $FILE_OWNER $MSG_CAT_DIR/$MSG_CAT_FILE
		$CHGRP $FILE_GROUP $MSG_CAT_DIR/$MSG_CAT_FILE
		$CHMOD $MSG_CAT_PERMS $MSG_CAT_DIR/$MSG_CAT_FILE
		echo "Done."
	fi
else
		echo "    Skipped at user request."
fi

echo
echo "Installation complete."
echo
exit

